@@ -1,17 +1,18 @@
 /* ============================================================
-*
-* SPDX-FileCopyrightText: 2007-2012 Kåre Särs <kare.sars@iki .fi>
-* SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
-*
-* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*
-* ============================================================ */
+ *
+ * SPDX-FileCopyrightText: 2007-2012 Kåre Särs <kare.sars@iki .fi>
+ * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
+ *
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ *
+ * ============================================================ */
 
-#include <QCommandLineParser>
 #include <QCommandLineOption>
+#include <QCommandLineParser>
 #include <QShortcut>
 
 #include <KAboutData>
+#include <KCrash>
 #include <KLocalizedString>
 
 #include "skanlite.h"
@@ -21,9 +22,6 @@
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("skanlite");
@@ -36,43 +34,37 @@ int main(int argc, char *argv[])
                          i18n("(C) 2008-2020 Kåre Särs"), // copyrightStatement
                          QString(), // other Text
                          QString() // homePageAddress
-                        );
+    );
 
-    aboutData.addAuthor(i18n("Kåre Särs"),
-                        i18n("developer"),
-                        QStringLiteral("kare.sars@iki.fi"));
+    aboutData.addAuthor(i18n("Kåre Särs"), i18n("developer"), QStringLiteral("kare.sars@iki.fi"));
 
-    aboutData.addAuthor(i18n("Gregor Mi"),
-                        i18n("contributor"));
+    aboutData.addAuthor(i18n("Gregor Mi"), i18n("contributor"));
 
-    aboutData.addAuthor(i18n("Arseniy Lartsev"),
-                        i18n("contributor"));
+    aboutData.addAuthor(i18n("Arseniy Lartsev"), i18n("contributor"));
 
-    aboutData.addCredit(i18n("Gilles Caulier"),
-                        i18n("Importing libksane to extragear"));
+    aboutData.addCredit(i18n("Gilles Caulier"), i18n("Importing libksane to extragear"));
 
-    aboutData.addCredit(i18n("Anne-Marie Mahfouf"),
-                        i18n("Writing the user manual"));
+    aboutData.addCredit(i18n("Anne-Marie Mahfouf"), i18n("Writing the user manual"));
 
-    aboutData.addCredit(i18n("Laurent Montel"),
-                        i18n("Importing libksane to extragear"));
+    aboutData.addCredit(i18n("Laurent Montel"), i18n("Importing libksane to extragear"));
 
-    aboutData.addCredit(i18n("Chusslove Illich"),
-                        i18n("Help with translations"));
+    aboutData.addCredit(i18n("Chusslove Illich"), i18n("Help with translations"));
 
-    aboutData.addCredit(i18n("Albert Astals Cid"),
-                        i18n("Help with translations"));
+    aboutData.addCredit(i18n("Albert Astals Cid"), i18n("Help with translations"));
 
     // Required for showing the translation list KXmlGui is not used
-    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"),
-                            i18nc("EMAIL OF TRANSLATORS", "Your emails"));
+    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("skanlite")));
     KAboutData::setApplicationData(aboutData);
 
+    KCrash::initialize();
+
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
-    QCommandLineOption deviceOption(QStringList() << QStringLiteral("d") << QStringLiteral("device"), i18n("Sane scanner device name. Use 'test' for test device."), i18n("device"));
+    QCommandLineOption deviceOption(QStringList() << QStringLiteral("d") << QStringLiteral("device"),
+                                    i18n("Sane scanner device name. Use 'test' for test device."),
+                                    i18n("device"));
     parser.addOption(deviceOption);
     parser.process(app); // the --author and --license is shown anyway but they work only with the following line
     aboutData.processCommandLine(&parser);
@@ -89,4 +81,3 @@ int main(int argc, char *argv[])
 
     return app.exec();
 }
-
